window.Gleam.initSearch([{"doc":"mungo","title":"mungo","content":"# mungo (formerly gleam_mongo)\n&gt; mungo: a felted fabric made from the shredded fibre of repurposed woollen cloth\n---\n\n\nA mongodb driver for gleam\n\n## Quick start\n\n```sh\ngleam shell # Run an Erlang shell\n```\n\n## Installation\n\n```sh\ngleam add mungo\n```\n\n## Roadmap\n\n- [x] support basic mongodb commands\n- [x] support aggregation\n- [x] support connection strings\n- [x] support authentication\n- [x] support mongodb cursors\n- [ ] support connection pooling\n- [ ] support bulk operations\n- [ ] support tls\n- [ ] support clusters\n- [ ] support transactions\n- [ ] support change streams\n- [ ] support other mongodb commands\n\n## Usage\n\n```gleam\nimport gleam/uri\nimport gleam/option\nimport mungo\nimport mungo/crud.{Sort, Upsert}\nimport mungo/aggregation.{Let, add_fields, aggregate, exec, match}\nimport bison/value\n\npub fn main() {\n  let encoded_password = uri.percent_encode(&quot;strong password&quot;)\n  let assert Ok(db) =\n    mungo.connect(\n      &quot;mongodb://app-dev:&quot; &lt;&gt; encoded_password &lt;&gt; &quot;@localhost/app-db?authSource=admin&quot;,\n    )\n\n  let users =\n    db\n    |&gt; mungo.collection(&quot;users&quot;)\n\n  let _ =\n    users\n    |&gt; mungo.insert_many([\n      value.Document([\n        #(&quot;username&quot;, value.Str(&quot;jmorrow&quot;)),\n        #(&quot;name&quot;, value.Str(&quot;vincent freeman&quot;)),\n        #(&quot;email&quot;, value.Str(&quot;jmorrow@gattaca.eu&quot;)),\n        #(&quot;age&quot;, value.Int32(32)),\n      ]),\n      value.Document([\n        #(&quot;username&quot;, value.Str(&quot;real-jerome&quot;)),\n        #(&quot;name&quot;, value.Str(&quot;jerome eugene morrow&quot;)),\n        #(&quot;email&quot;, value.Str(&quot;real-jerome@running.at&quot;)),\n        #(&quot;age&quot;, value.Int32(32)),\n      ]),\n    ])\n\n  let _ =\n    users\n    |&gt; mungo.update_one(\n      value.Document([#(&quot;username&quot;, value.Str(&quot;real-jerome&quot;))]),\n      value.Document([\n        #(\n          &quot;$set&quot;,\n          value.Document([\n            #(&quot;username&quot;, value.Str(&quot;eugene&quot;)),\n            #(&quot;email&quot;, value.Str(&quot;eugene@running.at &quot;)),\n          ]),\n        ),\n      ]),\n      [Upsert],\n    )\n\n  let assert Ok(yahoo_cursor) =\n    users\n    |&gt; mungo.find_many(\n      value.Document([#(&quot;email&quot;, value.Regex(#(&quot;yahoo&quot;, &quot;&quot;)))]),\n      [Sort(value.Document([#(&quot;username&quot;, value.Int32(-1))]))],\n    )\n  let _yahoo_users = mungo.to_list(yahoo_cursor)\n\n  let assert Ok(underage_lindsey_cursor) =\n    users\n    |&gt; aggregate([Let(value.Document([#(&quot;minimum_age&quot;, value.Int32(21))]))])\n    |&gt; match(value.Document([\n      #(\n        &quot;$expr&quot;,\n        value.Document([\n          #(&quot;$lt&quot;, value.Array([value.Str(&quot;$age&quot;), value.Str(&quot;$$minimum_age&quot;)])),\n        ]),\n      ),\n    ]))\n    |&gt; add_fields(value.Document([\n      #(\n        &quot;first_name&quot;,\n        value.Document([\n          #(\n            &quot;$arrayElemAt&quot;,\n            value.Array([\n              value.Document([\n                #(&quot;$split&quot;, value.Array([value.Str(&quot;$name&quot;), value.Str(&quot; &quot;)])),\n              ]),\n              value.Int32(0),\n            ]),\n          ),\n        ]),\n      ),\n    ]))\n    |&gt; match(value.Document([#(&quot;first_name&quot;, value.Str(&quot;lindsey&quot;))]))\n    |&gt; exec\n\n  let assert #(option.Some(_underage_lindsey), underage_lindsey_cursor) =\n    underage_lindsey_cursor\n    |&gt; mungo.next\n\n  let assert #(option.None, _) =\n    underage_lindsey_cursor\n    |&gt; mungo.next\n}\n```\n","url":"index.html"},{"doc":"mungo/utils","title":"MongoError","content":"pub type MongoError {\n  MongoError(code: Int, msg: String, source: value.Value)\n}\n\nMongoError(code: Int, msg: String, source: value.Value)\n\n\nSynonyms:\nmungo/utils.MongoError\nmungo/utils MongoError","url":"mungo/utils.html#MongoError"},{"doc":"mungo/utils","title":"default_error","content":"pub const default_error: MongoError = MongoError(\n  code: -16,\n  msg: &quot;&quot;,\n  source: value.Null,\n)\n\nSynonyms:\nmungo/utils.default_error\nmungo/utils default_error","url":"mungo/utils.html#default_error"},{"doc":"mungo/utils","title":"mungo/utils","content":"","url":"mungo/utils.html"},{"doc":"mungo/aggregation","title":"AggregateOption","content":"pub type AggregateOption {\n  BatchSize(Int)\n  Let(value.Value)\n}\n\nBatchSize(Int)\n\n\nLet(value.Value)\n\n\nSynonyms:\nmungo/aggregation.AggregateOption\nmungo/aggregation AggregateOption","url":"mungo/aggregation.html#AggregateOption"},{"doc":"mungo/aggregation","title":"Pipeline","content":"pub opaque type Pipeline\n\n\nSynonyms:\nmungo/aggregation.Pipeline\nmungo/aggregation Pipeline","url":"mungo/aggregation.html#Pipeline"},{"doc":"mungo/aggregation","title":"add_fields","content":"pub fn add_fields(pipeline: Pipeline, doc: Value) -&gt; Pipeline\n\nSynonyms:\nmungo/aggregation.add_fields\nmungo/aggregation add_fields","url":"mungo/aggregation.html#add_fields"},{"doc":"mungo/aggregation","title":"aggregate","content":"pub fn aggregate(collection: Collection, options: List(\n    AggregateOption,\n  )) -&gt; Pipeline\n\nSynonyms:\nmungo/aggregation.aggregate\nmungo/aggregation aggregate","url":"mungo/aggregation.html#aggregate"},{"doc":"mungo/aggregation","title":"exec","content":"pub fn exec(pipeline: Pipeline) -&gt; Result(Cursor, MongoError)\n\nSynonyms:\nmungo/aggregation.exec\nmungo/aggregation exec","url":"mungo/aggregation.html#exec"},{"doc":"mungo/aggregation","title":"group","content":"pub fn group(pipeline: Pipeline, doc: Value) -&gt; Pipeline\n\nSynonyms:\nmungo/aggregation.group\nmungo/aggregation group","url":"mungo/aggregation.html#group"},{"doc":"mungo/aggregation","title":"limit","content":"pub fn limit(pipeline: Pipeline, count: Int) -&gt; Pipeline\n\nSynonyms:\nmungo/aggregation.limit\nmungo/aggregation limit","url":"mungo/aggregation.html#limit"},{"doc":"mungo/aggregation","title":"lookup","content":"pub fn lookup(pipeline: Pipeline, from from: String, local_field local_field: String, foreign_field foreign_field: String, alias alias: String) -&gt; Pipeline\n\nSynonyms:\nmungo/aggregation.lookup\nmungo/aggregation lookup","url":"mungo/aggregation.html#lookup"},{"doc":"mungo/aggregation","title":"match","content":"pub fn match(pipeline: Pipeline, doc: Value) -&gt; Pipeline\n\nSynonyms:\nmungo/aggregation.match\nmungo/aggregation match","url":"mungo/aggregation.html#match"},{"doc":"mungo/aggregation","title":"project","content":"pub fn project(pipeline: Pipeline, doc: Value) -&gt; Pipeline\n\nSynonyms:\nmungo/aggregation.project\nmungo/aggregation project","url":"mungo/aggregation.html#project"},{"doc":"mungo/aggregation","title":"skip","content":"pub fn skip(pipeline: Pipeline, count: Int) -&gt; Pipeline\n\nSynonyms:\nmungo/aggregation.skip\nmungo/aggregation skip","url":"mungo/aggregation.html#skip"},{"doc":"mungo/aggregation","title":"sort","content":"pub fn sort(pipeline: Pipeline, doc: Value) -&gt; Pipeline\n\nSynonyms:\nmungo/aggregation.sort\nmungo/aggregation sort","url":"mungo/aggregation.html#sort"},{"doc":"mungo/aggregation","title":"stages","content":"pub fn stages(pipeline: Pipeline, docs: List(Value)) -&gt; Pipeline\n\nSynonyms:\nmungo/aggregation.stages\nmungo/aggregation stages","url":"mungo/aggregation.html#stages"},{"doc":"mungo/aggregation","title":"mungo/aggregation","content":"","url":"mungo/aggregation.html"},{"doc":"mungo/crud","title":"FindOption","content":"pub type FindOption {\n  Skip(Int)\n  Limit(Int)\n  BatchSize(Int)\n  Sort(value.Value)\n  Projection(value.Value)\n}\n\nSkip(Int)\n\n\nLimit(Int)\n\n\nBatchSize(Int)\n\n\nSort(value.Value)\n\n\nProjection(value.Value)\n\n\nSynonyms:\nmungo/crud.FindOption\nmungo/crud FindOption","url":"mungo/crud.html#FindOption"},{"doc":"mungo/crud","title":"InsertResult","content":"pub type InsertResult {\n  InsertResult(inserted: Int, inserted_ids: List(value.Value))\n}\n\nInsertResult(inserted: Int, inserted_ids: List(value.Value))\n\n\nSynonyms:\nmungo/crud.InsertResult\nmungo/crud InsertResult","url":"mungo/crud.html#InsertResult"},{"doc":"mungo/crud","title":"UpdateOption","content":"pub type UpdateOption {\n  Upsert\n  ArrayFilters(List(value.Value))\n}\n\nUpsert\n\n\nArrayFilters(List(value.Value))\n\n\nSynonyms:\nmungo/crud.UpdateOption\nmungo/crud UpdateOption","url":"mungo/crud.html#UpdateOption"},{"doc":"mungo/crud","title":"UpdateResult","content":"pub type UpdateResult {\n  UpdateResult(matched: Int, modified: Int)\n  UpsertResult(matched: Int, upserted_id: value.Value)\n}\n\nUpdateResult(matched: Int, modified: Int)\n\n\nUpsertResult(matched: Int, upserted_id: value.Value)\n\n\nSynonyms:\nmungo/crud.UpdateResult\nmungo/crud UpdateResult","url":"mungo/crud.html#UpdateResult"},{"doc":"mungo/crud","title":"count","content":"pub fn count(collection: Collection, filter: Value) -&gt; Result(\n  Int,\n  MongoError,\n)\n\nSynonyms:\nmungo/crud.count\nmungo/crud count","url":"mungo/crud.html#count"},{"doc":"mungo/crud","title":"count_all","content":"pub fn count_all(collection: Collection) -&gt; Result(\n  Int,\n  MongoError,\n)\n\nSynonyms:\nmungo/crud.count_all\nmungo/crud count_all","url":"mungo/crud.html#count_all"},{"doc":"mungo/crud","title":"delete_many","content":"pub fn delete_many(collection: Collection, filter: Value) -&gt; Result(\n  Int,\n  MongoError,\n)\n\nSynonyms:\nmungo/crud.delete_many\nmungo/crud delete_many","url":"mungo/crud.html#delete_many"},{"doc":"mungo/crud","title":"delete_one","content":"pub fn delete_one(collection: Collection, filter: Value) -&gt; Result(\n  Int,\n  MongoError,\n)\n\nSynonyms:\nmungo/crud.delete_one\nmungo/crud delete_one","url":"mungo/crud.html#delete_one"},{"doc":"mungo/crud","title":"find_all","content":"pub fn find_all(collection: Collection, options: List(FindOption)) -&gt; Result(\n  Cursor,\n  MongoError,\n)\n\nSynonyms:\nmungo/crud.find_all\nmungo/crud find_all","url":"mungo/crud.html#find_all"},{"doc":"mungo/crud","title":"find_by_id","content":"pub fn find_by_id(collection: Collection, id: String) -&gt; Result(\n  Option(Value),\n  MongoError,\n)\n\nSynonyms:\nmungo/crud.find_by_id\nmungo/crud find_by_id","url":"mungo/crud.html#find_by_id"},{"doc":"mungo/crud","title":"find_many","content":"pub fn find_many(collection: Collection, filter: Value, options: List(\n    FindOption,\n  )) -&gt; Result(Cursor, MongoError)\n\nSynonyms:\nmungo/crud.find_many\nmungo/crud find_many","url":"mungo/crud.html#find_many"},{"doc":"mungo/crud","title":"find_one","content":"pub fn find_one(collection: Collection, filter: Value, projection: Value) -&gt; Result(\n  Option(Value),\n  MongoError,\n)\n\nSynonyms:\nmungo/crud.find_one\nmungo/crud find_one","url":"mungo/crud.html#find_one"},{"doc":"mungo/crud","title":"insert_many","content":"pub fn insert_many(collection: Collection, docs: List(Value)) -&gt; Result(\n  InsertResult,\n  MongoError,\n)\n\nSynonyms:\nmungo/crud.insert_many\nmungo/crud insert_many","url":"mungo/crud.html#insert_many"},{"doc":"mungo/crud","title":"insert_one","content":"pub fn insert_one(collection: Collection, doc: Value) -&gt; Result(\n  Value,\n  MongoError,\n)\n\nSynonyms:\nmungo/crud.insert_one\nmungo/crud insert_one","url":"mungo/crud.html#insert_one"},{"doc":"mungo/crud","title":"update_many","content":"pub fn update_many(collection: Collection, filter: Value, change: Value, options: List(\n    UpdateOption,\n  )) -&gt; Result(UpdateResult, MongoError)\n\nSynonyms:\nmungo/crud.update_many\nmungo/crud update_many","url":"mungo/crud.html#update_many"},{"doc":"mungo/crud","title":"update_one","content":"pub fn update_one(collection: Collection, filter: Value, change: Value, options: List(\n    UpdateOption,\n  )) -&gt; Result(UpdateResult, MongoError)\n\nSynonyms:\nmungo/crud.update_one\nmungo/crud update_one","url":"mungo/crud.html#update_one"},{"doc":"mungo/crud","title":"mungo/crud","content":"","url":"mungo/crud.html"},{"doc":"mungo","title":"collection","content":"pub fn collection(db: Database, name: String) -&gt; Collection\n\nSynonyms:\nmungo.collection\nmungo collection","url":"mungo.html#collection"},{"doc":"mungo","title":"connect","content":"pub fn connect(uri: String) -&gt; Result(Database, Nil)\n\nSynonyms:\nmungo.connect\nmungo connect","url":"mungo.html#connect"},{"doc":"mungo","title":"count","content":"pub fn count(collection: Collection, filter: Value) -&gt; Result(\n  Int,\n  MongoError,\n)\n\nSynonyms:\nmungo.count\nmungo count","url":"mungo.html#count"},{"doc":"mungo","title":"count_all","content":"pub fn count_all(collection: Collection) -&gt; Result(\n  Int,\n  MongoError,\n)\n\nSynonyms:\nmungo.count_all\nmungo count_all","url":"mungo.html#count_all"},{"doc":"mungo","title":"delete_many","content":"pub fn delete_many(collection: Collection, filter: Value) -&gt; Result(\n  Int,\n  MongoError,\n)\n\nSynonyms:\nmungo.delete_many\nmungo delete_many","url":"mungo.html#delete_many"},{"doc":"mungo","title":"delete_one","content":"pub fn delete_one(collection: Collection, filter: Value) -&gt; Result(\n  Int,\n  MongoError,\n)\n\nSynonyms:\nmungo.delete_one\nmungo delete_one","url":"mungo.html#delete_one"},{"doc":"mungo","title":"find_all","content":"pub fn find_all(collection: Collection, options: List(FindOption)) -&gt; Result(\n  Cursor,\n  MongoError,\n)\n\nSynonyms:\nmungo.find_all\nmungo find_all","url":"mungo.html#find_all"},{"doc":"mungo","title":"find_by_id","content":"pub fn find_by_id(collection: Collection, id: String) -&gt; Result(\n  Option(Value),\n  MongoError,\n)\n\nSynonyms:\nmungo.find_by_id\nmungo find_by_id","url":"mungo.html#find_by_id"},{"doc":"mungo","title":"find_many","content":"pub fn find_many(collection: Collection, filter: Value, options: List(\n    FindOption,\n  )) -&gt; Result(Cursor, MongoError)\n\nSynonyms:\nmungo.find_many\nmungo find_many","url":"mungo.html#find_many"},{"doc":"mungo","title":"find_one","content":"pub fn find_one(collection: Collection, filter: Value, projection: Value) -&gt; Result(\n  Option(Value),\n  MongoError,\n)\n\nSynonyms:\nmungo.find_one\nmungo find_one","url":"mungo.html#find_one"},{"doc":"mungo","title":"insert_many","content":"pub fn insert_many(collection: Collection, docs: List(Value)) -&gt; Result(\n  InsertResult,\n  MongoError,\n)\n\nSynonyms:\nmungo.insert_many\nmungo insert_many","url":"mungo.html#insert_many"},{"doc":"mungo","title":"insert_one","content":"pub fn insert_one(collection: Collection, doc: Value) -&gt; Result(\n  Value,\n  MongoError,\n)\n\nSynonyms:\nmungo.insert_one\nmungo insert_one","url":"mungo.html#insert_one"},{"doc":"mungo","title":"next","content":"pub fn next(cursor: Cursor) -&gt; #(Option(Value), Cursor)\n\nSynonyms:\nmungo.next\nmungo next","url":"mungo.html#next"},{"doc":"mungo","title":"to_list","content":"pub fn to_list(cursor: Cursor) -&gt; List(Value)\n\nSynonyms:\nmungo.to_list\nmungo to_list","url":"mungo.html#to_list"},{"doc":"mungo","title":"update_many","content":"pub fn update_many(collection: Collection, filter: Value, change: Value, options: List(\n    UpdateOption,\n  )) -&gt; Result(UpdateResult, MongoError)\n\nSynonyms:\nmungo.update_many\nmungo update_many","url":"mungo.html#update_many"},{"doc":"mungo","title":"update_one","content":"pub fn update_one(collection: Collection, filter: Value, change: Value, options: List(\n    UpdateOption,\n  )) -&gt; Result(UpdateResult, MongoError)\n\nSynonyms:\nmungo.update_one\nmungo update_one","url":"mungo.html#update_one"},{"doc":"mungo","title":"mungo","content":"","url":"mungo.html"}]);